@@ -3,7 +3,6 @@
 
 from __future__ import print_function
 import requests
-import json
 
 
 class Base(object):
@@ -12,8 +11,9 @@ class Base(object):
                        '[GitHub Wiki](https://github.com/DenisCarriere/geocoder/wiki)']
     _exclude = ['parse', 'json', 'url', 'attributes', 'help', 'debug', 'short_name',
                 'api', 'description', 'content', 'params', 'status_code', 'headers',
-                'status_description', 'api_key', 'ok']
+                'status_description', 'api_key', 'ok', 'key', 'id']
     _example = []
+    _timeout = 5.0
     attributes = []
     headers = {}
 
@@ -57,7 +57,7 @@ class Base(object):
         print('## Python Example')
         print('')
         print('```python')
-        print('>>> import geocoder')
+        print('>>> import geocoder # pip install geocoder')
         if self._example:
             for line in self._example:
                 print(line)
@@ -97,7 +97,7 @@ class Base(object):
         self.status_code = 404
         self.status = 'Connecting...'
         try:
-            r = requests.get(self.url, params=self.params, headers=self.headers, timeout=5.0)
+            r = requests.get(self.url, params=self.params, headers=self.headers, timeout=self._timeout)
             self.status_code = r.status_code
             self.url = r.url
             self.status = 'OK'
@@ -246,4 +246,4 @@ class Base(object):
         if bool(self.lng and self.lat):
             return True
         else:
-            return False
\ No newline at end of file
+            return False
